Module algorithms

Module algorithms 

Algorithms using GBWT and GBZ.

Functions

fast_weighted_lcs
Returns the longest common subsequence of integer sequences a and b, weighted by the given function.
lcs
Returns the longest common subsequence of a and b.
naive_weighted_lcs
Returns the longest common subsequence of integer sequences a and b, weighted by the given function.
path_lcs
Returns the longest common subsequence of paths a and b in the graph.