PathName

Struct PathName 

#[repr(C)]
pub struct PathName { pub sample: u32, pub contig: u32, pub phase: u32, pub fragment: u32, }
A structured path name relative to Metadata.

Each path name in the same metadata structure must be unique. A path name has four components: sample, contig, phase (haplotype), and fragment (count).

  • Samples correspond to sample identifiers in the metadata.
  • Contigs correspond to contig identifiers in the metadata.
  • Each (sample, phase) combination corresponds to a haplotype in the metadata.
  • Fragment field can be used as a fragment index for fragments from the sequence identified by (sample, contig, phase). It can also be used as the starting offset of the fragment in the corresponding sequence.

See also FullPathName for a stand-alone structure that contains the same information.

Fields

sample: u32

Sample identifier.

contig: u32

Contig identifier.

phase: u32

Phase / haplotype identifier.

fragment: u32

Fragment identifier / running count.

Implementations

Source

impl PathName

pub fn new() -> Self

Returns a new path name with all components set to 0.

pub fn from_fields( sample: usize, contig: usize, phase: usize, fragment: usize, ) -> Self

Returns a path name with the given values in each field.

pub fn sample(&self) -> usize

Returns the sample identifier.

pub fn contig(&self) -> usize

Returns the contig identifier.

pub fn phase(&self) -> usize

Returns the phase / haplotype identifier.

pub fn fragment(&self) -> usize

Returns the fragment identifier / running count.