#[repr(C)]pub struct PathName {
pub sample: u32,
pub contig: u32,
pub phase: u32,
pub fragment: u32,
}Expand description
A structured path name relative to Metadata.
Each path name in the same metadata structure must be unique. A path name has four components: sample, contig, phase (haplotype), and fragment (count).
- Samples correspond to sample identifiers in the metadata.
- Contigs correspond to contig identifiers in the metadata.
- Each (sample, phase) combination corresponds to a haplotype in the metadata.
- Fragment field can be used as a fragment index for fragments from the sequence identified by (sample, contig, phase). It can also be used as the starting offset of the fragment in the corresponding sequence.
See also FullPathName for a stand-alone structure that contains the same information.
Fields
sample: u32Sample identifier.
contig: u32Contig identifier.
phase: u32Phase / haplotype identifier.
fragment: u32Fragment identifier / running count.
Implementations